﻿using System.Windows;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;
using System.Windows.Media.Imaging;
using System;
using System.IO;
using System.Drawing;

namespace DisplayASimpleMap
{
    public partial class Sample : Window
    {
        public Sample()
        {
            InitializeComponent();
        }

        private void LayoutRoot_Loaded(object sender, RoutedEventArgs e)
        {
            Map1.MapUnit = GeographyUnit.DecimalDegree;
            Map1.MapTools.Logo.IsEnabled = true;
            Map1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);

            WorldMapKitWmsWpfOverlay worldMapKitWmsWpfOverlay = new WorldMapKitWmsWpfOverlay();
            Map1.Overlays.Add(worldMapKitWmsWpfOverlay);

            BuildLegend();

            InMemoryFeatureLayer inmlaye = new InMemoryFeatureLayer();
            inmlaye.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            inmlaye.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.Capital1;
            inmlaye.InternalFeatures.Add(new Feature(0,0));

            LayerOverlay ov = new LayerOverlay();
            ov.Layers.Add(inmlaye);
            Map1.Overlays.Add(ov);

            Map1.CurrentExtent = new RectangleShape(-180, 90, 180, -90);
            Map1.Refresh();
        }

        private void button1_Click(object sender, RoutedEventArgs e)
        {
            System.Drawing.Bitmap mapbmp = Map1.GetBitmap(800, 800);

            mapbmp.Save(@"c:\temp\b.png");
        }

        private void BuildLegend()
        {
            //****************************************
            // Note:  Hard-coded styles were used in the LegendItems below to simplify the sample.  
            //        Typically, a LegendItem's ImageStyle property will be set to a style that is already 
            //        set on a layer in the map.
            // Example:
            //        legendItem.ImageStyle = Map1.FindFeatureLayer("myLayerName").ZoomLevelSet.ZoomLevel01.DefaultAreaStyle;
            //
            //****************************************
          
            // Create a legend item for the title.
            LegendItem title = new LegendItem();
            title.TextStyle = new TextStyle("Map Legend", new GeoFont("Arial", 10, DrawingFontStyles.Bold), new GeoSolidBrush(GeoColor.SimpleColors.Black));

            // Create a legend item for the state borders.  This example uses a modified LineStyle.
            LegendItem legendItem1 = new LegendItem();
            LineStyle stateBorderStyle = new LineStyle();
            stateBorderStyle.OuterPen.DashStyle = LineDashStyle.Dash;
            stateBorderStyle.OuterPen.Width = 2;
            stateBorderStyle.OuterPen.Color = GeoColor.FromArgb(255,156,155,154);
            legendItem1.ImageStyle = stateBorderStyle;
            legendItem1.TextStyle = new TextStyle("State Borders", new GeoFont("Arial", 8), new GeoSolidBrush(GeoColor.SimpleColors.Black));

            // Create a legend item for the state borders.  This example uses a simple AreaStyle.
            LegendItem legendItem2 = new LegendItem();
            legendItem2.ImageStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 167, 204, 149));
            legendItem2.TextStyle = new TextStyle("Forests", new GeoFont("Arial", 8), new GeoSolidBrush(GeoColor.SimpleColors.Black));
            
            // Create A legend item for the airports.  This example uses a .png file.
            LegendItem legendItem3 = new LegendItem();
            legendItem3.ImageStyle = new PointStyle(new GeoImage(@"..\..\Resources\airport_small_size3.png"));
            legendItem3.TextStyle = new TextStyle("Airports", new GeoFont("Arial", 8), new GeoSolidBrush(GeoColor.SimpleColors.Black));

            // Create the LegendAdornmentLayer and add the LegendItems.
            LegendAdornmentLayer legendLayer = new LegendAdornmentLayer();
            legendLayer.BackgroundMask = AreaStyles.CreateLinearGradientStyle(new GeoColor(255, 255, 255, 255), new GeoColor(255, 230, 230, 230), 90, GeoColor.SimpleColors.Black);
            legendLayer.LegendItems.Add(legendItem1);
            legendLayer.LegendItems.Add(legendItem2);
            legendLayer.LegendItems.Add(legendItem3);
            legendLayer.Height = 125;
            legendLayer.Title = title;
            legendLayer.Location = AdornmentLocation.LowerLeft;

            AdornmentOverlay adornmentOverlay = new AdornmentOverlay();
            //adornmentOverlay.IsBase = true;

            adornmentOverlay.Layers.Add("LengendLayer", legendLayer);
            Map1.Overlays.Add(adornmentOverlay);
        }

     
    }
}

